#!/usr/bin/praat --run

# prompt user for filename and tier number
form Get formants
   sentence Filename_of_sound dlf950728.1030.n1.wav
   sentence Filename_of_labelfile dlf950728.1030.n1.phones
   sentence Extract_formants_for_labels_matching ^(a:|E:|i:|o:|u:)$
endform

# shorten regexp variable
  labelexp$ = extract_formants_for_labels_matching$

# check sound if absolute path
if startsWith (filename_of_sound$, "/") 
   # absolute, so just copy the value into the shortened variable
   soundname$ = filename_of_sound$
else
   # relative, concatenate with shellDirectory
   soundname$ = shellDirectory$ + "/" + filename_of_sound$
endif
# open wav
sound = Read from file: soundname$

# check labelfile if absolute path
if startsWith (filename_of_labelfile$, "/") 
   # absolute, so just copy the value into the shortened variable
   labelfilename$ = filename_of_labelfile$
else
   # relative, concatenate with shellDirectory
   labelfilename$ = shellDirectory$ + "/" + filename_of_labelfile$
endif
# open labelfile
phones = Read IntervalTier from Xwaves: labelfilename$
textgrid = Into TextGrid

# clear info window
writeInfo()

# extract sounds corresponding to desired phones
selectObject: sound, textgrid
Extract intervals where: 1, "yes", "matches (regex)", labelexp$
# save IDs of all selected sounds in an array so we can delete them later
# get number of selected objects
n = numberOfSelected ()
for i to n
    # this gets the ID of the i-th selected object
    sound[i] = selected (i) 
endfor

# convert all extracted sounds to formants
To Formant (burg): 0, 5, 5500, 0.025, 50

# get number of selected objects
n = numberOfSelected ()
# save IDs of all selected formant objects in an array
for i to n
    # this gets the ID of the i-th selected object
    formant[i] = selected (i) 
endfor

# now iterate to extract formants
for i to n
    # select formant object
    selectObject: formant[i]
    # find middle time
    start = Get start time
    dur = Get total duration
    sampletime = start + 0.5*dur
    f1 = Get value at time: 1, sampletime, "Hertz", "Linear"
    f2 = Get value at time: 2, sampletime, "Hertz", "Linear"
    f3 = Get value at time: 3, sampletime, "Hertz", "Linear"
    # find out which vowel this was
    selectObject: textgrid
    interval = Get interval at time: 1, sampletime
    label$ = Get label of interval: 1, interval
    appendInfoLine: label$, " ", fixed$(sampletime,2), " ",fixed$( f1,0), " ", fixed$(f2,0), " ", fixed$(f3,0)
endfor

# clean up
selectObject: sound, phones, textgrid 
for i from 1 to n
    plusObject: formant[i], sound[i]
endfor
Remove
